==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-Lt1xxWI8pcKL4WQlupEMXJ

key:
    hls-explicit-record-fields-plugin-2.0.0.0-Lt1xxWI8pcKL4WQlupEMXJ

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4cbcbf917156103aa27289e5a8ab9c62
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-Lt1xxWI8pcKL4WQlupEMXJ

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-EWrlgTX7Fn4LLydhXCZ3jb
    hls-graph-2.0.0.0-GhTfsgGbH8zFTGMB6CXker
    hls-plugin-api-2.0.0.0-Kupf5YqCRZd4Ptteceoqgq
    lens-5.2.3-L3i2UjhlizAJHOs2jD5fLZ
    lsp-1.6.0.0-7wkYu5mVuH17doYFvcUgoA
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-6Ixsq3efxtjC6VCXGT8jZv

key:
    hls-explicit-record-fields-plugin-2.0.0.0-6Ixsq3efxtjC6VCXGT8jZv

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2c7604a1d8ba1a6d1dc923abe6d8771b
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-6Ixsq3efxtjC6VCXGT8jZv

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-LcUkn9k6LPTKoCzRiajHYT
    hls-graph-2.0.0.0-GhTfsgGbH8zFTGMB6CXker
    hls-plugin-api-2.0.0.0-GFx79nsP69yAcxi4XTe3K1
    lens-5.2.3-L3i2UjhlizAJHOs2jD5fLZ
    lsp-1.6.0.0-GGoyVQQ9vm28PxcyZzVzfj
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
